
Soma-base documentation
=======================

Many miscelaneous all-purpose classes and functions...

License: `CeCILL-B <http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html>`_


Main module: ``soma.api``
+++++++++++++++++++++++++

.. automodule:: soma.api
  :members:


Sub-modules
+++++++++++

SubModule: ``application``
--------------------------

:mod:`soma.application`


SubModule: ``bufferandfile``
----------------------------

:mod:`soma.bufferandfile`


SubModule: ``controller``
-------------------------

:ref:`controller`


SubModule: ``debug``
--------------------

:mod:`soma.debug`


SubModule: ``fom``
------------------

:mod:`soma.fom`


SubModule: ``gui``
------------------

:mod:`soma.gui`


SubModule: ``html``
-------------------

:mod:`soma.html`


SubModule: ``importer``
-----------------------

:mod:`soma.importer`


SubModule: ``minf``
-------------------

:mod:`soma.minf.api`


SubModule: ``notification``
---------------------------

:mod:`soma.notification`


SubModule: ``path``
-------------------

:mod:`soma.path`


SubModule: ``pyro``
-------------------

:mod:`soma.pyro`


SubModule: ``qt4gui``
---------------------

:mod:`soma.qt4gui`


SubModule: ``qt_gui``
---------------------

:mod:`soma.qt_gui`


SubModule: ``singleton``
------------------------

:mod:`soma.singleton`


SubModule: ``somatime``
-----------------------

:mod:`soma.somatime`


SubModule: ``sorted_dictionary``
--------------------------------

:mod:`soma.sorted_dictionary`


SubModule: ``stringtools``
--------------------------

:mod:`soma.stringtools`


SubModule: ``thread_calls``
---------------------------

:mod:`soma.thread_calls`


SubModule: ``translation``
--------------------------

:mod:`soma.translation`


SubModule: ``undefined``
------------------------

:mod:`soma.undefined`


SubModule: ``utils``
--------------------

:mod:`soma.utils`


SubModule: ``uuid``
-------------------

:mod:`soma.uuid`


SubModule: ``zipfile``
----------------------

:mod:`soma.zipfile`


.. toctree::
    :maxdepth: 1

    api.rst

